==> ejc-zjkjcost-impl-3.0.0-20220621.101220-3-sources.jar: com/ejianc/business/zjkjcost/finish/bean/ApplyDetailEntity.java <==
package com.ejianc.business.zjkjcost.finish.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 竣工考核-目标责任书竣工考核兑现申报-子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_zjkjcost_finish_apply_detail")
public class ApplyDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="apply_id")
    private Long applyId; // 申报主表id
    @TableField(value="unit")
    private String unit; // 单位
    @TableField(value="target_manage")
    private String targetManage; // 管理目标
    @TableField(value="target_duty")
    private String targetDuty; // 目标责任
    @TableField(value="target_finish")
    private String targetFinish; // 实现目标
    @TableField(value="opinion")
    private String opinion; // 会签意见
    @TableField(value="sign")
    private String sign; // 签名
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="edit_flag")
    private Integer editFlag; // 编辑性,1-可编辑,2-不可编辑
    
    
    

    public Long getApplyId() {
        return applyId;
    }

    public void setApplyId(Long applyId) {
        this.applyId = applyId;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public String getTargetManage() {
        return targetManage;
    }

    public void setTargetManage(String targetManage) {
        this.targetManage = targetManage;
    }
    public String getTargetDuty() {
        return targetDuty;
    }

    public void setTargetDuty(String targetDuty) {
        this.targetDuty = targetDuty;
    }
    public String getTargetFinish() {
        return targetFinish;
    }

    public void setTargetFinish(String targetFinish) {
        this.targetFinish = targetFinish;
    }
    public String getOpinion() {
        return opinion;
    }

    public void setOpinion(String opinion) {
        this.opinion = opinion;
    }
    public String getSign() {
        return sign;
    }

    public void setSign(String sign) {
        this.sign = sign;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Integer getEditFlag() {
        return editFlag;
    }

    public void setEditFlag(Integer editFlag) {
        this.editFlag = editFlag;
    }
    
}

==> ejc-zjkjcost-impl-3.0.0-20221103.065130-73-sources.jar: com/ejianc/business/zjkjcost/finish/bean/ApplyDetailEntity.java <==
package com.ejianc.business.zjkjcost.finish.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 竣工考核-目标责任书竣工考核兑现申报-子表
 *
 * @author generator
 *
 */
 @TableName("ejc_zjkjcost_finish_apply_detail")
public class ApplyDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="apply_id")
    private Long applyId; // 申报主表id
    @TableField(value="unit")
    private String unit; // 单位
    @TableField(value="target_manage")
    private String targetManage; // 管理目标
    @TableField(value="target_duty")
    private String targetDuty; // 目标责任
    @TableField(value="target_finish")
    private String targetFinish; // 实现目标
    @TableField(value="opinion")
    private String opinion; // 会签意见
    @TableField(value="sign")
    private String sign; // 签名
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="edit_flag")
    private Integer editFlag; // 编辑性,1-可编辑,2-不可编辑
    @TableField(value="init_flag")
    private Integer initFlag; // 是否为预置内容,0：否,1：是




    public Long getApplyId() {
        return applyId;
    }

    public void setApplyId(Long applyId) {
        this.applyId = applyId;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public String getTargetManage() {
        return targetManage;
    }

    public void setTargetManage(String targetManage) {
        this.targetManage = targetManage;
    }
    public String getTargetDuty() {
        return targetDuty;
    }

    public void setTargetDuty(String targetDuty) {
        this.targetDuty = targetDuty;
    }
    public String getTargetFinish() {
        return targetFinish;
    }

    public void setTargetFinish(String targetFinish) {
        this.targetFinish = targetFinish;
    }
    public String getOpinion() {
        return opinion;
    }

    public void setOpinion(String opinion) {
        this.opinion = opinion;
    }
    public String getSign() {
        return sign;
    }

    public void setSign(String sign) {
        this.sign = sign;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Integer getEditFlag() {
        return editFlag;
    }

    public void setEditFlag(Integer editFlag) {
        this.editFlag = editFlag;
    }

    public Integer getInitFlag() {
        return initFlag;
    }

    public void setInitFlag(Integer initFlag) {
        this.initFlag = initFlag;
    }
}
